package com.ruoyi.ems.service;

import com.ruoyi.ems.domain.ElecValencyHourStrategy;

import java.util.List;

/**
 * 电价策略小时Service接口
 * 
 * @author ruoyi
 * @date 2024-07-23
 */
public interface IElecValencyHourStrategyService
{
    /**
     * 查询电价策略小时
     * 
     * @param id 电价策略小时主键
     * @return 电价策略小时
     */
     ElecValencyHourStrategy selectHourStrategyById(Long id);

    /**
     * 查询电价策略小时列表
     * 
     * @param HourStrategy 电价策略小时
     * @return 电价策略小时集合
     */
     List<ElecValencyHourStrategy> selectHourStrategyList(ElecValencyHourStrategy HourStrategy);

    /**
     * 新增电价策略小时
     * 
     * @param HourStrategy 电价策略小时
     * @return 结果
     */
     int insertHourStrategy(ElecValencyHourStrategy HourStrategy);

    /**
     * 批量新增电价策略小时
     *
     * @param hourStrategys 电价策略小时列表
     * @return 结果
     */
     int insertHourStrategyList(List<ElecValencyHourStrategy> hourStrategys);

    /**
     * 修改电价策略小时
     * 
     * @param hourStrategy 电价策略小时
     * @return 结果
     */
     int updateHourStrategy(ElecValencyHourStrategy hourStrategy);

    /**
     * 批量删除电价策略小时
     * 
     * @param ids 需要删除的电价策略小时主键集合
     * @return 结果
     */
     int deleteHourStrategyByIds(Long[] ids);

    /**
     * 删除电价策略小时信息
     * 
     * @param id 电价策略小时主键
     * @return 结果
     */
     int deleteHourStrategyById(Long id);

    /**
     * 删除电价策略小时信息
     *
     * @param strategyCode 策略编码
     * @return 结果
     */
    int deleteHourStrategyByStrategy(String strategyCode);
}
